==> azureml_core-1.0.6-py2.py3-none-any.whl: azureml/_base_sdk_common/cli_wrapper/_common.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

"""
A file for base_sdk_common cli_wrapper functions.
"""

import os
import sys

from azureml._cli.aml_cli import AZUREML_CLI_IN_USE
from azureml._base_sdk_common.common import AZUREML_ARM_ACCESS_TOKEN, AZUREML_SUBSCRIPTION_ID
from azureml.core.authentication import ArmTokenAuthentication, AzureCliAuthentication
from azureml.core.workspace import Workspace
from azureml.exceptions import AuthenticationException
from azureml.exceptions import UserErrorException
from azureml._project.project import Project

try:  # python 3
    from configparser import ConfigParser
except ImportError:  # python 2
    from ConfigParser import ConfigParser


# DEFAULT MACRO NAMES for az configure defaults
DEFAULT_WORKSPACE_CONFIG_KEY = "aml_workspace"
DEFAULT_RESOURCE_GROUP_NAME_KEY = "group"


def get_cli_specific_auth():
    """
    Returns the cli specific auth.
    For azure.cli, returns an object of azureml.core.authentication.AzureCliAuthentication
    For azureml._cli, returns an object of azureml.core.authentication.ArmTokenAuthentication
    :return:
    :rtype: azureml.core.authentication.AbstractAuthentication
    """
    if AZUREML_CLI_IN_USE in os.environ and AZUREML_ARM_ACCESS_TOKEN in os.environ:
        return ArmTokenAuthentication(os.environ[AZUREML_ARM_ACCESS_TOKEN])

    # az cli case
    return AzureCliAuthentication()


def get_default_subscription_id(auth):
    """
    Returns the default subscription id based on the auth object type.
    This function could be removed later on.
    :param auth:
    :type auth: azureml.core.authentication.AbstractAuthentication
    :return: subscription id
    :rtype: str
    """
    if isinstance(auth, ArmTokenAuthentication):
        if AZUREML_SUBSCRIPTION_ID in os.environ:
            return os.environ[AZUREML_SUBSCRIPTION_ID]
        else:
            raise AuthenticationException("The default subscription id cannot be determined for "
                                          "auth object of type = {}".format(auth.__class__))
    elif isinstance(auth, AzureCliAuthentication):
        return auth._get_default_subscription_id()
    else:
        raise AuthenticationException("The default subscription id cannot be determined for "
                                      "auth object of type = {}".format(auth.__class__))


def get_cli_specific_output(command_output):
    """
    Returns CLI specific output.
    For azure.cli, makes some prints to stdout and the returns the JSON returned by the service.
    For azureml._cli, returns a JSON object without printing anything on stdout.
    :param command_output:
    :type command_output: CLICommandOutput
    :return:
    :rtype json:
    """
    if AZUREML_CLI_IN_USE not in os.environ:
        print(command_output.get_command_output())

        if not command_output.get_do_not_print_dict():
            # Returning the JSON object from service.
            return command_output.get_json_dict(exclude_command_output=True)
    else:
        # Return the full JSON in azureml._cli case.
        return command_output.get_json_dict()


def cli_exception_handler(ex):
    # Printing exception as sys.exit skips the exception trace.
    # sys.exit is okay for CLI commands, as each command is a python process, which finishes as
    # the command finishes.
    sys.exit(ex)


def get_default_property(property_name):
    """
    :return: Returns the default property value for property_name, if set using "az configure" command.
    Return None if no default value found.
    :rtype: str
    """
    config = ConfigParser()
    config.read(os.path.expanduser(os.path.join('~', '.azure', 'config')))
    if not config.has_section('defaults'):
        return None

    if config.has_option('defaults', property_name):
        return config.get('defaults', property_name)
    else:
        return None


def get_workspace_or_default_name(workspace_name, throw_error=False, auth=None, project_path=None):
    """
    Order is
    1) Get workspace name from the specified parameter,
    2) From project context,
    3) Using az configure defaults.
    :param auth:
    :type auth: azureml.core.authentication.AbstractAuthentication
    :param workspace_name:
    :type workspace_name: str
    :param throw_error: throw_error = True throws an error if eventual workspace_name=None
    :type throw_error: bool
    :return: Returns the provided or default value of the workspace name.
    """
    if not workspace_name:
        project_object = _get_project_object(auth=auth, project_path=project_path)
        if project_object:
            return project_object.workspace_object.name

        workspace_name = get_default_property(DEFAULT_WORKSPACE_CONFIG_KEY)
        if throw_error and not workspace_name:
            raise UserErrorException('Error, default workspace not set and workspace name parameter not provided.'
                                     '\nPlease run "az configure --defaults {}=<workspace name>" '
                                     'to set default workspace,\n or provide a value for the workspace name '
                                     'parameter.'.format(DEFAULT_WORKSPACE_CONFIG_KEY))
        else:
            return workspace_name
    else:
        return workspace_name


def get_resource_group_or_default_name(resource_group_name, throw_error=False, auth=None, project_path=None):
    """
    Order is
    1) Get workspace name from the specified parameter,
    2) From project context,
    3) Using az configure defaults.
    :param auth:
    :type auth: azureml.core.authentication.AbstractAuthentication
    :param resource_group_name:
    :type resource_group_name: str
    :param throw_error: throw_error = True throws an error if eventual resource_group_name=None
    :type throw_error: bool
    :param project_path:
    :type project_path: str
    :return: Returns the provided or default value of the resource_group_name.
    """
    if not resource_group_name:
        project_object = _get_project_object(auth=auth, project_path=project_path)
        if project_object:
            return project_object.workspace_object.resource_group

        resource_group_name = get_default_property(DEFAULT_RESOURCE_GROUP_NAME_KEY)
        if throw_error and not resource_group_name:
            raise UserErrorException('Error, default resource group not set.\n'
                                     'Please run "az configure --defaults group=<resource group name>" '
                                     'to set default resource group,\n or provide a value for the '
                                     '--resource-group parameter.')
        else:
            return resource_group_name
    else:
        return resource_group_name


def get_workspace_or_default(workspace_name=None, resource_group=None, auth=None, project_path=None):
    """
    Order is
    1) Get workspace from the specified parameters,
    2) From project context,
    3) Using az configure defaults.
    :param workspace_name:
    :param resource_group:
    :param auth:
    :param project_path:
    :return:
    """
    if not auth:
        auth = get_cli_specific_auth()

    default_subscription_id = get_default_subscription_id(auth)

    if resource_group and workspace_name:
        # Simple case where both are specified.
        return Workspace(default_subscription_id, resource_group, workspace_name, auth=auth)
    else:
        if not workspace_name:
            workspace_name = get_workspace_or_default_name(workspace_name, throw_error=True, auth=auth,
                                                           project_path=project_path)
        if not resource_group:
            resource_group = get_resource_group_or_default_name(resource_group, throw_error=True, auth=auth,
                                                                project_path=project_path)

        return Workspace(default_subscription_id, resource_group, workspace_name, auth=auth)


def _get_project_object(auth=None, project_path=None):
    if not auth:
        auth = get_cli_specific_auth()

    default_subscription_id = get_default_subscription_id(auth)

    project_object = None
    try:
        # We don't want to check if workspace exits or project even exists in service in this case
        # As we are using Project object just as a wrapper around project scope.
        project_object = Project(auth=auth, directory=project_path,
                                 _disable_service_check=True)
    except Exception:
        pass

    if project_object:
        if project_object.workspace_object.subscription_id != default_subscription_id:
            raise UserErrorException("Default CLI subscription id = {}, which doesn't match "
                                     "with the project subscription id = {} "
                                     "at location = {}".format(default_subscription_id,
                                                               project_object.workspace_object.subscription_id,
                                                               project_object.project_directory))
    return project_object

==> azureml_core-1.0.17-py2.py3-none-any.whl: azureml/_base_sdk_common/cli_wrapper/_common.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

"""
A file for base_sdk_common cli_wrapper functions.
"""

import os
import sys

from azureml._cli.aml_cli import AZUREML_CLI_IN_USE
from azureml._base_sdk_common.common import AZUREML_ARM_ACCESS_TOKEN, AZUREML_SUBSCRIPTION_ID
from azureml.core.authentication import ArmTokenAuthentication, AzureCliAuthentication
from azureml.core.workspace import Workspace
from azureml.exceptions import AuthenticationException
from azureml.exceptions import UserErrorException
from azureml._project.project import Project

try:  # python 3
    from configparser import ConfigParser
except ImportError:  # python 2
    from ConfigParser import ConfigParser


# DEFAULT MACRO NAMES for az configure defaults
DEFAULT_WORKSPACE_CONFIG_KEY = "aml_workspace"
DEFAULT_RESOURCE_GROUP_NAME_KEY = "group"


def get_cli_specific_auth():
    """
    Returns the cli specific auth.
    For azure.cli, returns an object of azureml.core.authentication.AzureCliAuthentication
    For azureml._cli, returns an object of azureml.core.authentication.ArmTokenAuthentication
    :return:
    :rtype: azureml.core.authentication.AbstractAuthentication
    """
    if AZUREML_CLI_IN_USE in os.environ and AZUREML_ARM_ACCESS_TOKEN in os.environ:
        return ArmTokenAuthentication(os.environ[AZUREML_ARM_ACCESS_TOKEN])

    # az cli case
    return AzureCliAuthentication()


def get_default_subscription_id(auth):
    """
    Returns the default subscription id based on the auth object type.
    This function could be removed later on.
    :param auth:
    :type auth: azureml.core.authentication.AbstractAuthentication
    :return: subscription id
    :rtype: str
    """
    if isinstance(auth, ArmTokenAuthentication):
        if AZUREML_SUBSCRIPTION_ID in os.environ:
            return os.environ[AZUREML_SUBSCRIPTION_ID]
        else:
            raise AuthenticationException("The default subscription id cannot be determined for "
                                          "auth object of type = {}".format(auth.__class__))
    elif isinstance(auth, AzureCliAuthentication):
        return auth._get_default_subscription_id()
    else:
        raise AuthenticationException("The default subscription id cannot be determined for "
                                      "auth object of type = {}".format(auth.__class__))


def get_cli_specific_output(command_output):
    """
    Returns CLI specific output.
    For azure.cli, makes some prints to stdout and the returns the JSON returned by the service.
    For azureml._cli, returns a JSON object without printing anything on stdout.
    :param command_output:
    :type command_output: CLICommandOutput
    :return:
    :rtype json:
    """
    if AZUREML_CLI_IN_USE not in os.environ:
        print(command_output.get_command_output())

        if not command_output.get_do_not_print_dict():
            # Returning the JSON object from service.
            return command_output.get_json_dict(exclude_command_output=True)
    else:
        # Return the full JSON in azureml._cli case.
        return command_output.get_json_dict()


def cli_exception_handler(ex):
    # Printing exception as sys.exit skips the exception trace.
    # sys.exit is okay for CLI commands, as each command is a python process, which finishes as
    # the command finishes.
    sys.exit(ex)


def get_default_property(property_name):
    """
    :return: Returns the default property value for property_name, if set using "az configure" command.
    Return None if no default value found.
    :rtype: str
    """
    config = ConfigParser()
    config.read(os.path.expanduser(os.path.join('~', '.azure', 'config')))
    if not config.has_section('defaults'):
        return None

    if config.has_option('defaults', property_name):
        return config.get('defaults', property_name)
    else:
        return None


def get_workspace_or_default_name(workspace_name, throw_error=False, auth=None, project_path=None):
    """
    Order is
    1) Get workspace name from the specified parameter,
    2) From project context,
    3) Using az configure defaults.
    :param auth:
    :type auth: azureml.core.authentication.AbstractAuthentication
    :param workspace_name:
    :type workspace_name: str
    :param throw_error: throw_error = True throws an error if eventual workspace_name=None
    :type throw_error: bool
    :return: Returns the provided or default value of the workspace name.
    """
    if not workspace_name:
        project_object = _get_project_object(auth=auth, project_path=project_path)
        if project_object:
            return project_object.workspace.name

        workspace_name = get_default_property(DEFAULT_WORKSPACE_CONFIG_KEY)
        if throw_error and not workspace_name:
            raise UserErrorException('Error, default workspace not set and workspace name parameter not provided.'
                                     '\nPlease run "az configure --defaults {}=<workspace name>" '
                                     'to set default workspace,\n or provide a value for the workspace name '
                                     'parameter.'.format(DEFAULT_WORKSPACE_CONFIG_KEY))
        else:
            return workspace_name
    else:
        return workspace_name


def get_resource_group_or_default_name(resource_group_name, throw_error=False, auth=None, project_path=None):
    """
    Order is
    1) Get workspace name from the specified parameter,
    2) From project context,
    3) Using az configure defaults.
    :param auth:
    :type auth: azureml.core.authentication.AbstractAuthentication
    :param resource_group_name:
    :type resource_group_name: str
    :param throw_error: throw_error = True throws an error if eventual resource_group_name=None
    :type throw_error: bool
    :param project_path:
    :type project_path: str
    :return: Returns the provided or default value of the resource_group_name.
    """
    if not resource_group_name:
        project_object = _get_project_object(auth=auth, project_path=project_path)
        if project_object:
            return project_object.workspace.resource_group

        resource_group_name = get_default_property(DEFAULT_RESOURCE_GROUP_NAME_KEY)
        if throw_error and not resource_group_name:
            raise UserErrorException('Error, default resource group not set.\n'
                                     'Please run "az configure --defaults group=<resource group name>" '
                                     'to set default resource group,\n or provide a value for the '
                                     '--resource-group parameter.')
        else:
            return resource_group_name
    else:
        return resource_group_name


def get_workspace_or_default(workspace_name=None, resource_group=None, auth=None, project_path=None):
    """
    Order is
    1) Get workspace from the specified parameters,
    2) From project context,
    3) Using az configure defaults.
    :param workspace_name:
    :param resource_group:
    :param auth:
    :param project_path:
    :return:
    """
    if not auth:
        auth = get_cli_specific_auth()

    default_subscription_id = get_default_subscription_id(auth)

    if resource_group and workspace_name:
        # Simple case where both are specified.
        return Workspace(default_subscription_id, resource_group, workspace_name, auth=auth)
    else:
        if not workspace_name:
            workspace_name = get_workspace_or_default_name(workspace_name, throw_error=True, auth=auth,
                                                           project_path=project_path)
        if not resource_group:
            resource_group = get_resource_group_or_default_name(resource_group, throw_error=True, auth=auth,
                                                                project_path=project_path)

        return Workspace(default_subscription_id, resource_group, workspace_name, auth=auth)


def _get_project_object(auth=None, project_path=None):
    if not auth:
        auth = get_cli_specific_auth()

    default_subscription_id = get_default_subscription_id(auth)

    project_object = None
    try:
        # We don't want to check if workspace exits or project even exists in service in this case
        # As we are using Project object just as a wrapper around project scope.
        project_object = Project(auth=auth, directory=project_path,
                                 _disable_service_check=True)
    except Exception:
        pass

    if project_object:
        if project_object.workspace.subscription_id != default_subscription_id:
            raise UserErrorException("Default CLI subscription id = {}, which doesn't match "
                                     "with the project subscription id = {} "
                                     "at location = {}".format(default_subscription_id,
                                                               project_object.workspace.subscription_id,
                                                               project_object.project_directory))
    return project_object
